@@ -110,7 +110,6 @@ dcRWRpipeline <- function(data, g, method=c("indirect","direct"), normalise=c("l
         stop("The function must apply to either 'igraph' or 'Dnetwork' object.\n")
     }
     
-    
     ####################################################
     # A function to indicate the running progress
     progress_indicate <- function(i, B, step, flag=F){
@@ -203,9 +202,21 @@ dcRWRpipeline <- function(data, g, method=c("indirect","direct"), normalise=c("l
     ###### parallel computing
     flag_parallel <- F
     if(parallel==TRUE){
+        
+        ############################
+        if(0){
+        pkgs <- c("doMC", "foreach")
+        if (any(pkgs %in% rownames(installed.packages()))) {
+            sapply(pkgs, function(pkg) {
+                suppressPackageStartupMessages(require(pkg, character.only = T))
+            })
+        }
+        }
+        ############################
+            
         flag_parallel <- dnet::dCheckParallel(multicores=multicores, verbose=verbose)
         if(flag_parallel){
-            exp_b <- foreach(b=1:B, .inorder=T) %dopar% {
+            exp_b <- foreach::`%dopar%` (foreach::foreach(b=1:B, .inorder=T), {
                 progress_indicate(b, B, 10, flag=T)
                 if(permutation=="degree"){
                     seeds_random <- dp_randomisation(ig, P0matrix)
@@ -222,7 +233,7 @@ dcRWRpipeline <- function(data, g, method=c("indirect","direct"), normalise=c("l
                     PTmatrix <- Matrix::Matrix(PTmatrix, sparse=T)
                 }
                 as.matrix(t(as.matrix(PT_random)) %*% PT_random)
-            }
+            })
         }
     }
     
